%%% Passive membrane code.  Brent Doiron, Sept 1, 2010.

clear all;
T=100; %simulation length
dt=0.005; %time discretization 
t_hat=10; %synaptic kicktime
V_CL=-70; %mV
V_syn=0;  %mV
g_syn=0.005; %mS/cm^2
g_CL=0.1; %mS/cm^2
C_m=1; %uF/cm^2
tau_syn=5;

N=ceil(T/dt); %vector lengths
N_hat=ceil(t_hat/dt); %kicktime index

V=zeros(1,N);
x=zeros(1,N);

% initial conditions
V(1)=V_CL;
x(1)=0;

for i=2:N  % Euler Integration Scheme
    
    V(i)=V(i-1)+dt*(-g_CL*(V(i-1)-V_CL)-g_syn*x(i-1)*(V(i-1)-V_syn));
    
    if (i==N_hat)  % synaptic kick?
        kick=1/dt;
    else    
        kick=0;
    end
    x(i)=x(i-1)+dt*(-x(i-1)/tau_syn+kick);
        
end    


time=[0:dt:T-dt];

% Plot some things
figure;
subplot(2,1,1), plot(time,V,'linewidth',2); xlabel('time (ms)','Fontsize',14), ylabel('Voltage (mV)', 'Fontsize',14);
subplot(2,1,2),plot(time,g_syn*x,'r','linewidth', 2); xlabel('time (ms)','Fontsize',14), ylabel('g_{syn} x (mS/cm^2)', 'Fontsize',14);
